Class: Pod::Command::Vipers
- Inherits:
-
Pod::Command
- Object
- Pod::Command
- Pod::Command::Vipers
- Defined in:
- lib/cocoapods-vipers/command/vipers.rb
Overview
Create a PR to add your plugin to CocoaPods/cocoapods.org in the plugins.json file, once your plugin is released.
This is an example of a cocoapods plugin adding a top-level subcommand to the ‘pod’ command.
You can also create subcommands of existing or new commands. Say you wanted to add a subcommand to list to show newly deprecated pods, (e.g. ‘pod list deprecated`), there are a few things that would need to change.
-
move this file to
lib/pod/command/list/deprecated.rband update the class to exist in the the Pod::Command::List namespace -
change this class to extend from
Listinstead ofCommand. This tells the plugin system that it is a subcommand oflist. -
edit
lib/cocoapods_plugins.rbto require this file
Instance Method Summary collapse
-
#initialize(argv) ⇒ Vipers
constructor
A new instance of Vipers.
- #run ⇒ Object
- #validate! ⇒ Object
Constructor Details
#initialize(argv) ⇒ Vipers
Returns a new instance of Vipers.
31 32 33 |
# File 'lib/cocoapods-vipers/command/vipers.rb', line 31 def initialize(argv) super end |
Instance Method Details
#run ⇒ Object
39 40 41 42 |
# File 'lib/cocoapods-vipers/command/vipers.rb', line 39 def run Pod::UI.puts "Use 'pod install' or 'pod update' to do vipers generate" # CocoapodsVipers::Vipers.new.sync() end |
#validate! ⇒ Object
35 36 37 |
# File 'lib/cocoapods-vipers/command/vipers.rb', line 35 def validate! super end |